import parserBabel from 'prettier/parser-babel';
import { format } from 'prettier/standalone';
import React, { useCallback, useMemo } from 'react';
import { PrismAsyncLight } from 'react-syntax-highlighter';
import { oneDark, oneLight } from 'react-syntax-highlighter/dist/esm/styles/prism';
import styled from 'styled-components';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }
  strings.raw = raw;
  return strings;
}

var CodeHighlighterTheme;
(function (CodeHighlighterTheme) {
  CodeHighlighterTheme["Light"] = "light";
  CodeHighlighterTheme["Dark"] = "dark";
})(CodeHighlighterTheme || (CodeHighlighterTheme = {}));

var _templateObject, _templateObject2, _templateObject3;
var StyledCodeHighlighter = /*#__PURE__*/styled.div(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    margin: 4px 0;\n    background-color: ", ";\n    border-radius: 8px;\n    padding-bottom: 6px;\n\n    pre {\n        margin: 0 !important;\n        overflow: auto;\n        padding: 1em;\n        line-height: 1.5;\n\n        // Styles for custom scrollbar\n\n        &::-webkit-scrollbar {\n            height: 5px;\n        }\n\n        &::-webkit-scrollbar-track {\n            background-color: transparent;\n        }\n\n        &::-webkit-scrollbar-button {\n            background-color: transparent;\n            height: 2px;\n        }\n\n        &::-webkit-scrollbar-thumb {\n\n            background-color: rgba(", ",\n            1);\n            border-radius: 20px;\n        }\n\n        // Scrollbar styles for Firefox. The above styles are not supported in Firefox, these styles are\n        // only supported in Firefox:\n\n        * {\n            scrollbar-color: rgba(", ",\n            1);\n        ) transparent;\n            scrollbar-width: thin;\n        }\n    }\n"])), function (_ref) {
  var codeTheme = _ref.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#282c34' : '#fafafa';
}, function (_ref2) {
  var codeTheme = _ref2.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '229, 229, 229' : '153, 153, 153';
}, function (_ref3) {
  var codeTheme = _ref3.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '229, 229, 229' : '153, 153, 153';
});
var StyledCodeHighlighterHeader = /*#__PURE__*/styled.div(_templateObject2 || (_templateObject2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    display: flex;\n    align-items: center;\n    justify-content: space-between;\n    border-bottom: 1px solid\n        ", ";\n    padding: 4px 12px;\n"])), function (_ref4) {
  var codeTheme = _ref4.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});
var StyledCodeHighlighterFileName = /*#__PURE__*/styled.span(_templateObject3 || (_templateObject3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n"])), function (_ref5) {
  var codeTheme = _ref5.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});

var _templateObject$1, _templateObject2$1, _templateObject3$1;
var StyledCopyToClipboard = /*#__PURE__*/styled.div(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    display: flex;\n    align-items: center;\n"])));
var StyledCopyToClipboardIcon = /*#__PURE__*/styled.i(_templateObject2$1 || (_templateObject2$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n"])), function (_ref) {
  var codeTheme = _ref.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});
var StyledCopyToClipboardText = /*#__PURE__*/styled.span(_templateObject3$1 || (_templateObject3$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n    font-size: small;\n    margin-left: 4px;\n"])), function (_ref2) {
  var codeTheme = _ref2.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});

var CopyToClipboard = function CopyToClipboard(_ref) {
  var copyButtonText = _ref.copyButtonText,
    text = _ref.text,
    theme = _ref.theme;
  var handleClick = function handleClick() {
    void navigator.clipboard.writeText(text);
  };
  return React.createElement(StyledCopyToClipboard, {
    onClick: handleClick
  }, React.createElement(StyledCopyToClipboardIcon, {
    className: "fa-regular fa-clipboard",
    codeTheme: theme
  }), copyButtonText && React.createElement(StyledCopyToClipboardText, {
    codeTheme: theme
  }, copyButtonText));
};
CopyToClipboard.displayName = 'CopyToClipboard';

var prettierOptions = {
  parser: 'babel',
  plugins: [parserBabel]
};
var CodeHighlighter = function CodeHighlighter(_ref) {
  var _ref$theme = _ref.theme,
    theme = _ref$theme === void 0 ? CodeHighlighterTheme.Dark : _ref$theme,
    code = _ref.code,
    copyButtonText = _ref.copyButtonText,
    _ref$formatConfig = _ref.formatConfig,
    formatConfig = _ref$formatConfig === void 0 ? prettierOptions : _ref$formatConfig,
    language = _ref.language,
    highlightedLines = _ref.highlightedLines,
    _ref$shouldShowLineNu = _ref.shouldShowLineNumbers,
    shouldShowLineNumbers = _ref$shouldShowLineNu === void 0 ? false : _ref$shouldShowLineNu;
  // function to style highlighted code
  var lineWrapper = useCallback(function (lineNumber) {
    var style = {
      backgroundColor: 'none',
      display: 'block',
      borderRadius: '2px'
    };
    if (highlightedLines != null && highlightedLines.added && highlightedLines.added.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#2EF29930'
      });
    } else if (highlightedLines != null && highlightedLines.removed && highlightedLines.removed.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#F22E5B30'
      });
    } else if (highlightedLines != null && highlightedLines.marked && highlightedLines.marked.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#cccccc40'
      });
    }
    return {
      style: style
    };
  }, [highlightedLines]);
  return useMemo(function () {
    return React.createElement(StyledCodeHighlighter, {
      codeTheme: theme
    }, React.createElement(StyledCodeHighlighterHeader, {
      codeTheme: theme
    }, React.createElement(StyledCodeHighlighterFileName, {
      codeTheme: theme
    }, language), React.createElement(CopyToClipboard, {
      text: code,
      theme: theme,
      copyButtonText: copyButtonText
    })), React.createElement(PrismAsyncLight, {
      language: language,
      showLineNumbers: shouldShowLineNumbers,
      style: theme === CodeHighlighterTheme.Dark ? oneDark : oneLight,
      wrapLines: true,
      lineProps: lineWrapper
    }, language === 'markdown' ? code : format(code, formatConfig)));
  }, [theme, language, code, copyButtonText, shouldShowLineNumbers, lineWrapper, formatConfig]);
};
CodeHighlighter.displayName = "CodeHighlighter";

export { CodeHighlighter, CodeHighlighterTheme };
//# sourceMappingURL=code-highlighter-react.esm.js.map
